import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { createOrUpdateContactsService, getContactBySesionService } from "@/feature/messenger/services/chat/OptionsMessageService";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import { useEffect, useState } from "react";
import toast from 'react-hot-toast';

const useContacts = () => {

    //hooks
    const openModalEditContact = useHandleConversationStore((state) => state.openModalEditContact);
    const handleOpenModalEditContact = useHandleConversationStore((state) => state.actions.handleOpenModalEditContact);

    //stores
    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const id_chatbot = useConfigChatStore(state => state.idChatbot);

    //state
    const [loading, setLoading] = useState(false);
    const [dissmiss, setDissmiss] = useState(true);
    const [isExistsContact, setIsExistsContact] = useState(false);
    const [formContacts, setFormContacts] = useState({
        id:null,
        name: '',
        city: '',
        email: '',
        address: '',
        state: '',
        management1: '',
        management2: '',
        sesion: selectedConversation.sesion
    })


    //functions
    const toggleContacts = () => {
        handleOpenModalEditContact()
    }

    const handleSubmitContacts = async (e: any) => {
        e.preventDefault();
        sendContactForm();
    }

    const getContactBySesion = async () => {
        const res = await getContactBySesionService(id_chatbot, selectedConversation.sesion)
        const response = res
        if (response.success == true) {
            setFormContacts({
                ...formContacts,
                id: response.data.id,
                name: response.data.nombre,
                city: response.data.ciudad,
                email: response.data.mail,
                address: response.data.direccion,
                state: response.data.status,
                management1: response.data.campo1,
                management2: response.data.campo2
            })
            setIsExistsContact(true)
            setDissmiss(false)
        }else{
            setFormContacts({
                ...formContacts,
                id: null,
                name: '',
                city: '',
                email: '',
                address: '',
                state: '',
                management1: '',
                management2: '',
                sesion: selectedConversation.sesion
            })
        }
    }

    const hadlerChangeForm = (e: any) => {
        setFormContacts({
            ...formContacts,
            [e.target.name]: e.target.value
        })
    }

    const sendContactForm = async () => {
        setLoading(true)
        const res = await createOrUpdateContactsService(id_chatbot, selectedConversation.sesion, formContacts)
        const response = res
        if (response.success == true) {
            toast.success("Se ha guardado correctamente el contacto")
        }else{
            toast.error("Ocurrio un error al guardar los datos")
        }
        setLoading(false)
        handleOpenModalEditContact()
        if(formContacts.id == null){
            setFormContacts({
                id: null,
                name: '',
                city: '',
                email: '',
                address: '',
                state: '',
                management1: '',
                management2: '',
                sesion: selectedConversation.sesion
            })
        }
    }

    useEffect(() => {
        if (openModalEditContact) {
            getContactBySesion()
            setTimeout(() => {
                setDissmiss(false)
            }, 7000); 
        }
    },[openModalEditContact])

    return {
        openModalEditContact,
        toggleContacts,
        formContacts,
        hadlerChangeForm,
        handleSubmitContacts,
        isExistsContact,
        dissmiss,
        selectedConversation,
        loading
    }
}

export default useContacts